@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _LOG_VIEW_EXPORT_H_
-#define _LOG_VIEW_EXPORT_H_
+#ifndef LOG_VIEW_EXPORT_H
+#define LOG_VIEW_EXPORT_H
 
 #include <QObject>
 #include <QPainter>
@@ -45,7 +45,7 @@ public:
 
     void printSelection();
 
-signals:
+Q_SIGNALS:
     void statusBarChanged(const QString &message);
 
 private:
@@ -56,4 +56,4 @@ private:
     LogViewWidget *logViewWidget;
 };
 
-#endif //_LOG_VIEW_EXPORT_H_
+#endif //_LOG_VIEW_EXPORT_H
